#!/usr/bin/env python
#
# GABI - Genome Assembly by Bayesian Inference
#
# Copyright 2013-2014, Brown University, Providence, RI. All Rights Reserved.
#
# This file is part of GABI.
#
# GABI is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# GABI is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GABI.  If not, see <http://www.gnu.org/licenses/>.

import os
import subprocess
import sys

from Bio import SeqIO
from collections import defaultdict

from graph import Graph
from biolite import utils


def load_fasta(filename):
	records = {}
	for record in SeqIO.parse(open(filename), 'fasta'):
		records[record.id] = record.seq
	return records


def find_edges(edges, reference):
	"""
	"""
	found = set()
	for e, edge in enumerate(edges, start=1):
		for ref in reference.itervalues():
			if ref.find(edge) >= 0 or ref.reverse_complement().find(edge) >= 0:
				found.add(e)
				break
	return found


if __name__ == '__main__':
	if utils.which('dot') is None:
		utils.die("could not find 'dot' command from graphviz")
	graph = Graph(sys.argv[1])
	edges = [record.seq for record in graph.fasta_edges()]
	n = max(3, len(sys.argv[2:]))
	for i, reference in enumerate(sys.argv[2:], start=1):
		name = os.path.splitext(os.path.basename(reference))[0]
		color = '/set1%d/%d' % (n,i)
		colors = {}
		for e in find_edges(edges, load_fasta(reference)):
			colors[e] = color
		graph.write_dot('compare%d.dot' % i, colors=colors)
		subprocess.check_call(
			['dot', '-Tpdf', '-Kneato', 'compare%d.dot' % i],
			stdout=open('compare%d.pdf' % i, 'w'))
		subprocess.check_call(
			['dot', '-Tsvg', '-Kneato', 'compare%d.dot' % i],
			stdout=open('compare%d.svg' % i, 'w'))

