#!/usr/bin/env python
# vim: set fileencoding=utf-8
#
# GABI - Genome Assembly by Bayesian Inference
#
# Copyright 2013-2014, Brown University, Providence, RI. All Rights Reserved.
#
# This file is part of GABI.
#
# GABI is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# GABI is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GABI.  If not, see <http://www.gnu.org/licenses/>.

import math
import matplotlib
matplotlib.use('Agg')

import numpy as np
import os
import sqlite3
import sys

from itertools import chain, combinations
from operator import itemgetter
from matplotlib.pyplot import *

matplotlib.rcParams.update({'font.size': 8})

letters = 'abcde'

def split_frequency_plot(names, traces, outname):
	"""
	Split frequencies at the final sample for each trace, compared against
	the first trace.
	"""

	n = len(names) + 1

	nsamples = []
	frequencies = []

	for trace in traces:
		db = sqlite3.connect(trace)
		sql = """
			SELECT COUNT(*)
			FROM samples
			WHERE accept=1
			ORDER BY id;"""
		nsamples.append(int(db.execute(sql).fetchone()[0]))
		sql = """
			SELECT edge, COUNT(edge)/%d.0
			FROM states JOIN samples ON states.id=samples.id
			WHERE accept=1
			GROUP BY edge;""" % nsamples[-1]
		frequencies.append(dict(db.execute(sql)))
		db.close()

	edges = set()
	map(edges.update, frequencies)
	edges = sorted(edges, key=(lambda e : frequencies[0].get(e, 0.0)))

	figure(figsize=(6,8))

	x = np.array([frequencies[0].get(e, 0.0) for e in edges])
	for i in xrange(0, len(names)):
		subplot(len(names), 1, i+1)
		title('(%c) %s' % (letters[i], names[i]), size=9, weight='heavy')
		xlim([0, len(edges)])
		xticks([])
		grid(axis='x')
		if i == len(names)-1:
			xlabel("Edges sorted by ascending frequency at k=10")
		ylim([-1, 1])
		if i == len(names)/2:
			ylabel(u"∆ frequency")
		y = np.array([frequencies[i+1].get(e, 0.0) for e in edges])
		y -= x
		axhline(y=0, alpha=0.5, c='k', lw=0.5)
		for i in xrange(0, len(edges)):
			c = min(1.0, math.sqrt(abs(4*y[i])))
			bar(i + 0.1, y[i], linewidth=0, facecolor=(c,0,0))
		#bar(np.arange(len(edges)) + 0.1, y, color=get_cmap('YlOrRd'))

	tight_layout()
	savefig(outname)


if __name__ == '__main__':
	names = sys.argv[1].split(',')
	print names
	split_frequency_plot(names, sys.argv[2:], 'priors.pdf')

